@@ -18,16 +18,19 @@ def register_service(
     config_options = config_options
     service = Service(
         name=Settings.service_name,
-        internal_domain="http://%s:3500" % internal_domain,
-        external_domain="https://%s" % hostname,
+        internal_domain=f"http://{internal_domain}:3500",
+        external_domain=f"https://{hostname}",
         status=ServiceStatus.HEALTHY,
         mem_percent=psutil.virtual_memory().percent,
         cpu_percent=psutil.cpu_percent(),
         config_options=config_options,
+        user_register_endpoint="/api/sso/register",
+        user_unregister_endpoint="/api/sso/unregister",
+        user_login_endpoint="/api/sso/login",
     )
     registration_url = Settings.sso_domain + "/register"
     try:
-        resp = requests.post(registration_url, json=service.dict())
+        resp = requests.post(registration_url, json=service.dict(), timeout=5)
         resp.close()
         response_error_check(resp)
     except Exception as e:
@@ -40,7 +43,7 @@ def unregister_service():
             Settings.sso_domain + "/unregister?service_name=%s" % Settings.service_name
         )
         try:
-            resp = requests.post(unregister_url)
+            resp = requests.post(unregister_url, timeout=5)
             resp.close()
             response_error_check(resp)
         except Exception as e:
