@@ -8,6 +8,7 @@ from pydantic import AnyHttpUrl, BaseModel, EmailStr
 class ConfigType(str, Enum):
     STRING = "str"
     INT = "int"
+    BOOLEAN = "bool"
 
 
 class ConfigConstraint(BaseModel):
@@ -34,9 +35,9 @@ class Service(BaseModel):
     name: str
     internal_domain: AnyHttpUrl
     external_domain: AnyHttpUrl
-    user_register_endpoint: str = "/api/sso/register"
-    user_unregister_endpoint: str = "/api/sso/unregister"
-    user_login_endpoint: str = "/api/sso/login"
+    user_register_endpoint: str
+    user_unregister_endpoint: str
+    user_login_endpoint: str
     status: ServiceStatus = ServiceStatus.DOWN
     mem_percent: float
     cpu_percent: float
@@ -61,6 +62,7 @@ class AwesomeUser(Document):
     email: EmailStr
     sso_user_id: PydanticObjectId
     settings: Dict[str, Any] = {}
+    line_linked: bool = False
 
     class Collection:
         name = "user"
