@@ -6,7 +6,9 @@ from awesome_sso.service.user.schema import AwesomeUserType
 
 async def sync_user(user: AwesomeUserType):
     resp = requests.get(
-        "%s/user" % Settings.sso_domain, params={"user_id": str(user.sso_user_id)}, timeout=5
+        "%s/user" % Settings.sso_domain,
+        params={"user_id": str(user.sso_user_id)},
+        timeout=5,
     )
     resp.close()
     if resp.status_code / 2 != 100:
@@ -16,6 +18,7 @@ async def sync_user(user: AwesomeUserType):
     sso_user = resp.json()
     user.email = sso_user["email"]
     user.name = sso_user["name"]
+    user.line_linked = sso_user["line_linked"]
     services = sso_user["services"]
     services_info = []
     config_values = {}
